<?php

namespace Drupal\youtube_block;

use Drupal\Core\Config\ConfigFactory;
use Drupal\key\KeyRepository;
use Madcoda\Youtube\Youtube;

/**
 * Class YoutubeBlockService.
 */
class YoutubeBlockService {

  /**
   * The config factory object.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * The key repository object.
   *
   * @var \Drupal\key\KeyRepository
   */
  protected $keyRepository;

  /**
   * The YouTube client.
   *
   * @var \Madcoda\Youtube\Youtube
   */
  private $client;

  /**
   * @param \Drupal\Core\Config\ConfigFactory $config_factory
   *   The config factory.
   * @param \Drupal\key\KeyRepository $key_repository
   *   The key repository.
   */
  public function __construct(ConfigFactory $config_factory, KeyRepository $key_repository) {
    $this->configFactory = $config_factory;
    $this->keyRepository = $key_repository;
  }

  /**
   * Get Api Key.
   *
   * @return string|null
   */
  public function getAPIKey(): ?string {
    $apiKeyName = $this->configFactory->get('youtube_block.settings')->get('api_key_name');
    $apiKey = NULL;
    if (!empty($apiKeyName)) {
      $apiKey = $this->keyRepository->getKey($apiKeyName)->getKeyValue();
    }
    return $apiKey;
  }

  /**
   * Get API client.
   *
   * @return \Madcoda\Youtube\Youtube
   *
   * @throws \Exception
   */
  public function getClient(): Youtube {
    if (!$this->client) {
      $this->client = new Youtube(['key' => $this->getAPIKey()]);
    }
    return $this->client;
  }

  /**
   * Get video info.
   *
   * @param string $vid
   *
   * @return false|\StdClass
   *
   * @throws \Exception
   */
  public function getVideoInfo($vid) {
    return $this->getClient()->getVideoInfo($vid);
  }

  /**
   * Get channel by username.
   *
   * @param string $username
   *
   * @return false|\StdClass
   *
   * @throws \Exception
   */
  public function getChannelByName($username) {
    return $this->getClient()->getChannelByName($username);
  }

  /**
   * Get channel by id.
   *
   * @param string $id
   *
   * @return false|\StdClass
   * @throws \Exception
   */
  public function getChannelById($id) {
    return $this->getClient()->getChannelById($id);
  }

  /**
   * Get playlists by channel id.
   *
   * @param string $id
   *
   * @return array|false
   *
   * @throws \Exception
   */
  public function getPlaylistsByChannelId($id) {
    return $this->getClient()->getPlaylistsByChannelId($id);
  }

  /**
   * Get playlist by id.
   *
   * @param string $id
   *
   * @return false|\StdClass
   *
   * @throws \Exception
   */
  public function getPlaylistById($id) {
    return $this->getClient()->getPlaylistById($id);
  }

  /**
   * Get playlist items by playlist id.
   *
   * @param string $id
   * @param int $maxResults
   *
   * @return array|false
   *
   * @throws \Exception
   */
  public function getPlaylistItemsByPlaylistId($id, $maxResults = 50) {
    return $this->getClient()->getPlaylistItemsByPlaylistId($id, $maxResults);
  }
}
